package com.vendor.platform.ui.internal;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.platform.core.PlatformCoreActivator;
import com.vendor.platform.ui.PlatformUIActivator;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Properties;
import org.eclipse.core.runtime.Platform;
import org.eclipse.core.runtime.Plugin;
import org.eclipse.osgi.service.datalocation.Location;

public class IniUtils {
  public static final String NL_KEY = "osgi.nl";
  
  public static final String DEFAULT_ECLIPSE_INI = "eclipse.ini";
  
  public static final String DEFAULT_ECLIPSE_CONFIG_INI = "config.ini";
  
  public static File findConfigFile() {
    Location installLocation = Platform.getInstallLocation();
    String file = installLocation.getURL().getFile();
    File installFolder = new File(file);
    if (installFolder.exists()) {
      File ini = new File(installFolder, "configuration" + File.separator + "config.ini");
      if (ini.exists())
        return ini; 
    } 
    return null;
  }
  
  public static void updateIniConfiguration(String key, String value) {
    File ini = findConfigFile();
    if (ini != null && ini.exists())
      updateSetting(ini, key, value); 
  }
  
  public static String getIniConfiguration(String key) {
    File ini = findConfigFile();
    if (ini != null && ini.exists())
      return getSetting(ini, key); 
    return "";
  }
  
  public static String getSetting(File ini, String key) {
    FileInputStream input = null;
    String rs = "";
    try {
      input = new FileInputStream(ini);
      Properties prop = new Properties();
      prop.load(input);
      if (prop.get(key) != null)
        rs = String.valueOf(prop.get(key)); 
    } catch (Exception e) {
      PlatformCoreActivator.getLogger((Plugin)PlatformUIActivator.getDefault())
        .logError(e.getMessage(), e);
    } finally {
      if (input != null)
        try {
          input.close();
        } catch (IOException e) {
          PlatformCoreActivator.getLogger(
              (Plugin)PlatformUIActivator.getDefault()).logError(e
              .getMessage(), e);
        }  
    } 
    return rs;
  }
  
  public static void updateSetting(File ini, String key, String value) {
    FileInputStream input = null;
    Properties prop = null;
    try {
      input = new FileInputStream(ini);
      prop = new Properties();
      prop.load(input);
      prop.put(key, value);
    } catch (Exception e) {
      PlatformCoreActivator.getLogger((Plugin)PlatformUIActivator.getDefault())
        .logError(e.getMessage(), e);
      return;
    } finally {
      try {
        if (input != null)
          input.close(); 
      } catch (IOException e) {
        PlatformCoreActivator.getLogger(
            (Plugin)PlatformUIActivator.getDefault()).logError(e
            .getMessage(), e);
        return;
      } 
    } 
    if (prop != null && prop.size() > 0) {
      FileOutputStream output = null;
      try {
        output = new FileOutputStream(ini);
        prop.store(output, (String)null);
      } catch (Exception e) {
        PlatformCoreActivator.getLogger(
            (Plugin)PlatformUIActivator.getDefault()).logError(e
            .getMessage(), e);
      } finally {
        try {
          if (output != null)
            output.close(); 
        } catch (IOException e) {
          PlatformCoreActivator.getLogger(
              (Plugin)PlatformUIActivator.getDefault()).logError(e
              .getMessage(), e);
        } 
      } 
    } 
  }
}
